@@ -10,6 +10,7 @@ class DistributeApp(ncdistributerlib.Distributor):
 This application will package a script for distribution.
 Usage:
     {appname} <filename>...
+    {appname} [--exclude-path=<path> --exclude-path=<path>] <filename>
     {appname} -h | --help
 
     """.format(appname=sys.argv[0])
@@ -20,6 +21,7 @@ Usage:
     
     
 if __name__ == "__main__":
-    A = DistributeApp()
-    A.arguments = docopt.docopt(DistributeApp.__doc__)
+    arguments = docopt.docopt(DistributeApp.__doc__)
+    A = DistributeApp(exclude_path_list=arguments["--exclude-path"])
+    A.arguments = arguments
     A.run()
